# Readme

Demeter is a backtest tool for DEFI. Please go to the [website](https://zelos-demeter.readthedocs.io/) for a full description

## Links

* website: https://zelos-demeter.readthedocs.io/
* Medium: https://medium.com/zelos-research
* Pypi: https://pypi.org/project/zelos-demeter
* demeter-fetch: https://github.com/zelos-alpha/demeter-fetch
